# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ml_server.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'ml_server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fml_server.proto\x12\x0clt_ml_server\"P\n\x0e\x41nalyzeRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x30\n\x07options\x18\x02 \x01(\x0b\x32\x1f.lt_ml_server.ProcessingOptions\"\xd7\x02\n\x11ProcessingOptions\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0f\n\x07tempOff\x18\x02 \x01(\x08\x12\x34\n\x05level\x18\x03 \x01(\x0e\x32%.lt_ml_server.ProcessingOptions.Level\x12\x0f\n\x07premium\x18\x04 \x01(\x08\x12\x13\n\x0b\x65nabledOnly\x18\x05 \x01(\x08\x12\x14\n\x0c\x65nabledRules\x18\x06 \x03(\t\x12\x15\n\rdisabledRules\x18\x07 \x03(\t\"\x95\x01\n\x05Level\x12\t\n\x05picky\x10\x00\x12\x0c\n\x08\x61\x63\x61\x64\x65mic\x10\x01\x12\x0b\n\x07\x63larity\x10\x02\x12\x10\n\x0cprofessional\x10\x03\x12\x0c\n\x08\x63reative\x10\x04\x12\x0c\n\x08\x63ustomer\x10\x05\x12\n\n\x06jobapp\x10\x06\x12\r\n\tobjective\x10\x07\x12\x0b\n\x07\x65legant\x10\x08\x12\x10\n\x0c\x64\x65\x66\x61ultLevel\x10\t\"D\n\x0f\x41nalyzeResponse\x12\x31\n\tsentences\x18\x01 \x03(\x0b\x32\x1e.lt_ml_server.AnalyzedSentence\"u\n\x0eProcessRequest\x12\x31\n\tsentences\x18\x01 \x03(\x0b\x32\x1e.lt_ml_server.AnalyzedSentence\x12\x30\n\x07options\x18\x02 \x01(\x0b\x32\x1f.lt_ml_server.ProcessingOptions\"`\n\x0fProcessResponse\x12\'\n\nrawMatches\x18\x01 \x03(\x0b\x32\x13.lt_ml_server.Match\x12$\n\x07matches\x18\x02 \x03(\x0b\x32\x13.lt_ml_server.Match\"v\n\x14\x41nalyzedMatchRequest\x12\x31\n\tsentences\x18\x01 \x03(\x0b\x32\x1e.lt_ml_server.AnalyzedSentence\x12\x14\n\x0cinputLogging\x18\x02 \x01(\x08\x12\x15\n\rtextSessionID\x18\x03 \x03(\x03\"U\n\x10\x41nalyzedSentence\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x33\n\x06tokens\x18\x02 \x03(\x0b\x32#.lt_ml_server.AnalyzedTokenReadings\"k\n\x15\x41nalyzedTokenReadings\x12-\n\x08readings\x18\x01 \x03(\x0b\x32\x1b.lt_ml_server.AnalyzedToken\x12\x11\n\tchunkTags\x18\x02 \x03(\t\x12\x10\n\x08startPos\x18\x03 \x01(\x05\"=\n\rAnalyzedToken\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0e\n\x06posTag\x18\x02 \x01(\t\x12\r\n\x05lemma\x18\x03 \x01(\t\"\x81\x01\n\x15PostProcessingRequest\x12\x11\n\tsentences\x18\x01 \x03(\t\x12(\n\x07matches\x18\x02 \x03(\x0b\x32\x17.lt_ml_server.MatchList\x12\x14\n\x0cinputLogging\x18\x03 \x01(\x08\x12\x15\n\rtextSessionID\x18\x04 \x03(\x03\"N\n\x0cMatchRequest\x12\x11\n\tsentences\x18\x01 \x03(\t\x12\x14\n\x0cinputLogging\x18\x02 \x01(\x08\x12\x15\n\rtextSessionID\x18\x03 \x03(\x03\"A\n\rMatchResponse\x12\x30\n\x0fsentenceMatches\x18\x01 \x03(\x0b\x32\x17.lt_ml_server.MatchList\"1\n\tMatchList\x12$\n\x07matches\x18\x01 \x03(\x0b\x32\x13.lt_ml_server.Match\"\xae\x03\n\x05Match\x12\x0e\n\x06offset\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06sub_id\x18\x04 \x01(\t\x12\x13\n\x0bsuggestions\x18\x05 \x03(\t\x12\x17\n\x0fruleDescription\x18\x06 \x01(\t\x12\x18\n\x10matchDescription\x18\x07 \x01(\t\x12\x1d\n\x15matchShortDescription\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x41\n\x15suggestedReplacements\x18\n \x03(\x0b\x32\".lt_ml_server.SuggestedReplacement\x12\x13\n\x0b\x61utoCorrect\x18\x0b \x01(\x08\x12+\n\x04type\x18\x0c \x01(\x0e\x32\x1d.lt_ml_server.Match.MatchType\x12\x1b\n\x13\x63ontextForSureMatch\x18\r \x01(\x11\x12 \n\x04rule\x18\x0e \x01(\x0b\x32\x12.lt_ml_server.Rule\"1\n\tMatchType\x12\x0f\n\x0bUnknownWord\x10\x00\x12\x08\n\x04Hint\x10\x01\x12\t\n\x05Other\x10\x02\"\xa9\x02\n\x04Rule\x12\x12\n\nsourceFile\x18\x01 \x01(\t\x12\x11\n\tissueType\x18\x02 \x01(\t\x12\x0f\n\x07tempOff\x18\x03 \x01(\x08\x12,\n\x08\x63\x61tegory\x18\x04 \x01(\x0b\x32\x1a.lt_ml_server.RuleCategory\x12\x11\n\tisPremium\x18\x05 \x01(\x08\x12$\n\x04tags\x18\x06 \x03(\x0e\x32\x16.lt_ml_server.Rule.Tag\"\x81\x01\n\x03Tag\x12\t\n\x05picky\x10\x00\x12\x0c\n\x08\x61\x63\x61\x64\x65mic\x10\x01\x12\x0b\n\x07\x63larity\x10\x02\x12\x10\n\x0cprofessional\x10\x03\x12\x0c\n\x08\x63reative\x10\x04\x12\x0c\n\x08\x63ustomer\x10\x05\x12\n\n\x06jobapp\x10\x06\x12\r\n\tobjective\x10\x07\x12\x0b\n\x07\x65legant\x10\x08\"(\n\x0cRuleCategory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xe2\x01\n\x14SuggestedReplacement\x12\x13\n\x0breplacement\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06suffix\x18\x03 \x01(\t\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12?\n\x04type\x18\x05 \x01(\x0e\x32\x31.lt_ml_server.SuggestedReplacement.SuggestionType\";\n\x0eSuggestionType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x0f\n\x0bTranslation\x10\x01\x12\x0b\n\x07\x43urated\x10\x02\x32\xa6\x01\n\x10ProcessingServer\x12H\n\x07\x41nalyze\x12\x1c.lt_ml_server.AnalyzeRequest\x1a\x1d.lt_ml_server.AnalyzeResponse\"\x00\x12H\n\x07Process\x12\x1c.lt_ml_server.ProcessRequest\x1a\x1d.lt_ml_server.ProcessResponse\"\x00\x32\xa2\x01\n\x08MLServer\x12\x42\n\x05Match\x12\x1a.lt_ml_server.MatchRequest\x1a\x1b.lt_ml_server.MatchResponse\"\x00\x12R\n\rMatchAnalyzed\x12\".lt_ml_server.AnalyzedMatchRequest\x1a\x1b.lt_ml_server.MatchResponse\"\x00\x32\x65\n\x14PostProcessingServer\x12M\n\x07Process\x12#.lt_ml_server.PostProcessingRequest\x1a\x1b.lt_ml_server.MatchResponse\"\x00\x42*\n\x19org.languagetool.rules.mlB\rMLServerProtob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ml_server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031org.languagetool.rules.mlB\rMLServerProto'
  _globals['_ANALYZEREQUEST']._serialized_start=33
  _globals['_ANALYZEREQUEST']._serialized_end=113
  _globals['_PROCESSINGOPTIONS']._serialized_start=116
  _globals['_PROCESSINGOPTIONS']._serialized_end=459
  _globals['_PROCESSINGOPTIONS_LEVEL']._serialized_start=310
  _globals['_PROCESSINGOPTIONS_LEVEL']._serialized_end=459
  _globals['_ANALYZERESPONSE']._serialized_start=461
  _globals['_ANALYZERESPONSE']._serialized_end=529
  _globals['_PROCESSREQUEST']._serialized_start=531
  _globals['_PROCESSREQUEST']._serialized_end=648
  _globals['_PROCESSRESPONSE']._serialized_start=650
  _globals['_PROCESSRESPONSE']._serialized_end=746
  _globals['_ANALYZEDMATCHREQUEST']._serialized_start=748
  _globals['_ANALYZEDMATCHREQUEST']._serialized_end=866
  _globals['_ANALYZEDSENTENCE']._serialized_start=868
  _globals['_ANALYZEDSENTENCE']._serialized_end=953
  _globals['_ANALYZEDTOKENREADINGS']._serialized_start=955
  _globals['_ANALYZEDTOKENREADINGS']._serialized_end=1062
  _globals['_ANALYZEDTOKEN']._serialized_start=1064
  _globals['_ANALYZEDTOKEN']._serialized_end=1125
  _globals['_POSTPROCESSINGREQUEST']._serialized_start=1128
  _globals['_POSTPROCESSINGREQUEST']._serialized_end=1257
  _globals['_MATCHREQUEST']._serialized_start=1259
  _globals['_MATCHREQUEST']._serialized_end=1337
  _globals['_MATCHRESPONSE']._serialized_start=1339
  _globals['_MATCHRESPONSE']._serialized_end=1404
  _globals['_MATCHLIST']._serialized_start=1406
  _globals['_MATCHLIST']._serialized_end=1455
  _globals['_MATCH']._serialized_start=1458
  _globals['_MATCH']._serialized_end=1888
  _globals['_MATCH_MATCHTYPE']._serialized_start=1839
  _globals['_MATCH_MATCHTYPE']._serialized_end=1888
  _globals['_RULE']._serialized_start=1891
  _globals['_RULE']._serialized_end=2188
  _globals['_RULE_TAG']._serialized_start=2059
  _globals['_RULE_TAG']._serialized_end=2188
  _globals['_RULECATEGORY']._serialized_start=2190
  _globals['_RULECATEGORY']._serialized_end=2230
  _globals['_SUGGESTEDREPLACEMENT']._serialized_start=2233
  _globals['_SUGGESTEDREPLACEMENT']._serialized_end=2459
  _globals['_SUGGESTEDREPLACEMENT_SUGGESTIONTYPE']._serialized_start=2400
  _globals['_SUGGESTEDREPLACEMENT_SUGGESTIONTYPE']._serialized_end=2459
  _globals['_PROCESSINGSERVER']._serialized_start=2462
  _globals['_PROCESSINGSERVER']._serialized_end=2628
  _globals['_MLSERVER']._serialized_start=2631
  _globals['_MLSERVER']._serialized_end=2793
  _globals['_POSTPROCESSINGSERVER']._serialized_start=2795
  _globals['_POSTPROCESSINGSERVER']._serialized_end=2896
# @@protoc_insertion_point(module_scope)
