"""
CoEdIT model for Triton Inference Server

This model uses the HuggingFace transformers library to serve the models
"""
from grammared_language.triton.triton_text2text_model import TritonText2TextPythonModel

class TritonPythonModel(TritonText2TextPythonModel):
    ...