"""
Auto-generated gRPC protocol buffer code from LanguageTool's ml_server.proto.

This module contains auto-generated code from ml_server.proto.
The files are named grammar_check_pb2* because that's what protoc generates
from the protobuf package name, but they implement the ml_server protocol.

Do not manually edit files in this module - regenerate using:

    python generate_grpc.py

"""

from . import ml_server_pb2
from . import ml_server_pb2_grpc

__all__ = ['ml_server_pb2', 'ml_server_pb2_grpc']


